psychopy_ext.exp.Experiment.create_win — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Experiment.create_win

`Experiment.` `create_win`(debug=False, color='DimGray', units='deg', winType='pyglet', **kwargs)

  Generates a `psychopy.visual.Window` for presenting stimuli.

  Kwargs: | debug (bool, default: False) If True, then the window is half the screen size. If False, then the windon is full screen. color (str, str with a hexadecimal value, or a tuple of 3 values, default: “DimGray’) Window background color. Default is dark gray. (See accepted color names